pub struct PreviousBootDataProviderOptions {
pub format: Option<InspectFormat>,
/* private fields */
}Expand description
Options for configuring the watcher.
Fields
format: Option<InspectFormat>Trait Implementations
Sourceimpl Clone for PreviousBootDataProviderOptions
impl Clone for PreviousBootDataProviderOptions
Sourcefn clone(&self) -> PreviousBootDataProviderOptions
fn clone(&self) -> PreviousBootDataProviderOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<PreviousBootDataProviderOptions, D> for PreviousBootDataProviderOptions
impl<D: ResourceDialect> Decode<PreviousBootDataProviderOptions, D> for PreviousBootDataProviderOptions
Sourceimpl Default for PreviousBootDataProviderOptions
impl Default for PreviousBootDataProviderOptions
Sourcefn default() -> PreviousBootDataProviderOptions
fn default() -> PreviousBootDataProviderOptions
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<PreviousBootDataProviderOptions, D> for &PreviousBootDataProviderOptions
impl<D: ResourceDialect> Encode<PreviousBootDataProviderOptions, D> for &PreviousBootDataProviderOptions
impl Persistable for PreviousBootDataProviderOptions
impl StructuralPartialEq for PreviousBootDataProviderOptions
Sourceimpl TypeMarker for PreviousBootDataProviderOptions
impl TypeMarker for PreviousBootDataProviderOptions
Sourcetype Owned = PreviousBootDataProviderOptions
type Owned = PreviousBootDataProviderOptions
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PreviousBootDataProviderOptions
impl ValueTypeMarker for PreviousBootDataProviderOptions
Sourcetype Borrowed<'a> = &'a PreviousBootDataProviderOptions
type Borrowed<'a> = &'a PreviousBootDataProviderOptions
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for PreviousBootDataProviderOptions
impl RefUnwindSafe for PreviousBootDataProviderOptions
impl Send for PreviousBootDataProviderOptions
impl Sync for PreviousBootDataProviderOptions
impl Unpin for PreviousBootDataProviderOptions
impl UnsafeUnpin for PreviousBootDataProviderOptions
impl UnwindSafe for PreviousBootDataProviderOptions